==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_entities/kittemplate_001/KitTemplate.java <==

package net.datastream.schemas.mp_entities.kittemplate_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.KITID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KITID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KITQUANTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NOTES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "kitid",
    "kitquantity",
    "notes",
    "uomcode",
    "partconditiontemplateconditioncode"
})
@XmlRootElement(name = "KitTemplate")
public class KitTemplate {

    @XmlElement(name = "KITID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected KITID_Type kitid;
    @XmlElement(name = "KITQUANTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY kitquantity;
    @XmlElement(name = "NOTES", namespace = "http://schemas.datastream.net/MP_fields")
    protected String notes;
    @XmlElement(name = "UOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String uomcode;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété kitid.
     * 
     * @return
     *     possible object is
     *     {@link KITID_Type }
     *     
     */
    public KITID_Type getKITID() {
        return kitid;
    }

    /**
     * Définit la valeur de la propriété kitid.
     * 
     * @param value
     *     allowed object is
     *     {@link KITID_Type }
     *     
     */
    public void setKITID(KITID_Type value) {
        this.kitid = value;
    }

    /**
     * Obtient la valeur de la propriété kitquantity.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getKITQUANTITY() {
        return kitquantity;
    }

    /**
     * Définit la valeur de la propriété kitquantity.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setKITQUANTITY(QUANTITY value) {
        this.kitquantity = value;
    }

    /**
     * Obtient la valeur de la propriété notes.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNOTES() {
        return notes;
    }

    /**
     * Définit la valeur de la propriété notes.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNOTES(String value) {
        this.notes = value;
    }

    /**
     * Obtient la valeur de la propriété uomcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOMCODE() {
        return uomcode;
    }

    /**
     * Définit la valeur de la propriété uomcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOMCODE(String value) {
        this.uomcode = value;
    }

    /**
     * Obtient la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Définit la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_entities/kittemplate_001/KitTemplate.java <==

package net.datastream.schemas.mp_entities.kittemplate_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.KITID_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KITID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KITQUANTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NOTES" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "kitid",
    "kitquantity",
    "notes",
    "uomcode",
    "partconditiontemplateconditioncode"
})
@XmlRootElement(name = "KitTemplate")
public class KitTemplate {

    @XmlElement(name = "KITID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected KITID_Type kitid;
    @XmlElement(name = "KITQUANTITY", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY kitquantity;
    @XmlElement(name = "NOTES", namespace = "http://schemas.datastream.net/MP_fields")
    protected String notes;
    @XmlElement(name = "UOMCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String uomcode;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the kitid property.
     * 
     * @return
     *     possible object is
     *     {@link KITID_Type }
     *     
     */
    public KITID_Type getKITID() {
        return kitid;
    }

    /**
     * Sets the value of the kitid property.
     * 
     * @param value
     *     allowed object is
     *     {@link KITID_Type }
     *     
     */
    public void setKITID(KITID_Type value) {
        this.kitid = value;
    }

    /**
     * Gets the value of the kitquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getKITQUANTITY() {
        return kitquantity;
    }

    /**
     * Sets the value of the kitquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setKITQUANTITY(QUANTITY value) {
        this.kitquantity = value;
    }

    /**
     * Gets the value of the notes property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNOTES() {
        return notes;
    }

    /**
     * Sets the value of the notes property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNOTES(String value) {
        this.notes = value;
    }

    /**
     * Gets the value of the uomcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOMCODE() {
        return uomcode;
    }

    /**
     * Sets the value of the uomcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOMCODE(String value) {
        this.uomcode = value;
    }

    /**
     * Gets the value of the partconditiontemplateconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Sets the value of the partconditiontemplateconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
